summaryrefslogtreecommitdiff
path: root/src/mongo/db/exec/and_sorted.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/exec/and_sorted.h')
-rw-r--r--src/mongo/db/exec/and_sorted.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mongo/db/exec/and_sorted.h b/src/mongo/db/exec/and_sorted.h
index 285cd9614ac..b6c3a9ed10e 100644
--- a/src/mongo/db/exec/and_sorted.h
+++ b/src/mongo/db/exec/and_sorted.h
@@ -40,15 +40,15 @@
namespace mongo {
/**
* Reads from N children, each of which must have a valid DiskLoc. Assumes each child produces
* DiskLocs in sorted order. Outputs the intersection of the DiskLocs outputted by the
* children.
*
* Preconditions: Valid DiskLoc. More than one child.
*
* Any DiskLoc that we keep a reference to that is invalidated before we are able to return it
* is fetched and added to the WorkingSet as "flagged for further review." Because this stage
- * operates with DiskLocs, we are unable to evaluate the AND for the invalidated DiskLoc, and it
+ * operates with RecordIds, we are unable to evaluate the AND for the invalidated RecordId, and it
* must be fully matched later.
*/
class AndSortedStage : public PlanStage {
@@ -63,7 +63,7 @@ namespace mongo {
virtual void saveState();
virtual void restoreState(OperationContext* opCtx);
- virtual void invalidate(OperationContext* txn, const DiskLoc& dl, InvalidationType type);
+ virtual void invalidate(OperationContext* txn, const RecordId& dl, InvalidationType type);
virtual std::vector<PlanStage*> getChildren() const;
@@ -99,7 +99,7 @@ namespace mongo {
// The current node we're AND-ing against.
size_t _targetNode;
- DiskLoc _targetLoc;
+ RecordId _targetLoc;
WorkingSetID _targetId;
// Nodes we're moving forward until they hit the element we're AND-ing.
@@ -40,15 +40,15 @@
namespace mongo {
/**
- * Reads from N children, each of which must have a valid DiskLoc. Assumes each child produces
- * DiskLocs in sorted order. Outputs the intersection of the DiskLocs outputted by the
+ * Reads from N children, each of which must have a valid RecordId. Assumes each child produces
+ * RecordIds in sorted order. Outputs the intersection of the RecordIds outputted by the
* children.
*
@@ -40,15 +40,15 @@
* children.
*
- * Preconditions: Valid DiskLoc. More than one child.
+ * Preconditions: Valid RecordId. More than one child.
*
@@ -40,15 +40,15 @@
*
- * Any DiskLoc that we keep a reference to that is invalidated before we are able to return it
+ * Any RecordId that we keep a reference to that is invalidated before we are able to return it
* is fetched and added to the WorkingSet as "flagged for further review." Because this stage